# Time Selector (Calendar)
- https://madewithvuejs.com/calendars
  - clean week & day https://kalendar.altinselimi.com/
  - https://clickermonkey.github.io/dayspan-vuetify/example/ almost google
    calendar
